# *vortezwohl-sdk*

> Useful Python SDKs

## Installation

- With pip

    ```
    pip install -U vortezwohl
    ```

- With uv

    ```
    uv add -U vortezwohl
    ```

- From github

    ```
    pip install -U git+https://github.com/vortezwohl/vortezwohl-sdk.git
    ```

## Key Features

- **cache**:

    - BaseCache

    - LRUCache

- **concurrent**:

    - ThreadPool

    - lock_on

- **io**:

    - read_file

    - write_file

    - get_files

    - size_of

- **nlp**:

    - LevenshteinDistance

    - LongestCommonSubstring

- **crypt**:

    - md5

    - sha1

    - sha256

    - sha512

- **random**:

    - next_seed
